#!/bin/sh
# full_backup.sh <darextra> <remotelogin> <remotedir> <basename>
# darextra = relative path from / to backup, directories to ignore...
if [ $# -ne 4 ]; then
  echo 1>&2 "Usage: $0 <darextra> <remotelogin> <remotedir> <basename>"
  exit 127
fi

# some configuration
DATE_Y_M=`date +%Y-%m`

# directory for remote storage ($3 = remotedir, append year and month)
BACKUP_DIR="$3/${DATE_Y_M}"

# directory for local storage (catalogs and pointers to last backup)
LOCAL_DIR="/home/backup"

REMOTE_LOGIN=$2
DARCMD="/usr/local/bin/dar -z7 -c - $1"
DATE=`date +%Y%m%d_%H%M`
FILE="${4}_${DATE}_full"
REMOTE_CMD="mkdir -p ${BACKUP_DIR}; cd ${BACKUP_DIR}; cat >${FILE}.1.dar"
#echo $DARCMD
#echo $REMOTE_CMD

# -- step 1 create backup
CMD1="$DARCMD | ssh $REMOTE_LOGIN '$REMOTE_CMD'"
#echo $CMD1
sh -c "$CMD1"

# -- step 2 create catalog and send back to client
mkdir -p ${LOCAL_DIR}/${DATE_Y_M}
REMOTE_CMD="cd ${BACKUP_DIR}; dar -w -A $FILE -C ${FILE}_CAT -z7"
CMD2="ssh >/dev/null -2 $REMOTE_LOGIN '$REMOTE_CMD'; scp -q $REMOTE_LOGIN:~/${BACKUP_DIR}/${FILE}_CAT.1.dar ${LOCAL_DIR}/${DATE_Y_M}"
#echo $CMD2
sh -c "$CMD2"

# -- step 3 store name of last full backup
cd ${LOCAL_DIR}
if [ -f ${DATE_Y_M}/${FILE}_CAT.1.dar ]; then
  echo >${4}_latest_full ${DATE_Y_M}/${FILE}

  # -- step 4 remove pointers to last incremental and diff backups
  rm ${4}_latest_incr
  rm ${4}_latest_diff
fi

